@@ -124,10 +124,10 @@ class DBAPICursor(with_metaclass(abc.ABCMeta, object)):
         :py:meth:`execute` did not produce any result set or no call was issued yet.
         """
         _logger.info("Commons - fetch many.... size - {}".format(size))
-        if size is None:
-            size = self.arraysize
-        # return list(islice(iter(self.fetchone, None), size))
-        return list(self.fetchone())
+        rowsToReturn = self.fetchone()
+        if rowsToReturn is None:
+            return None
+        return list(rowsToReturn)
 
     def fetchall(self):
         """Fetch all (remaining) rows of a query result, returning them as a sequence of sequences
